@@ -62,7 +62,7 @@ derived from Curses::UI::TextEditor. The
 only special thing about this class is that the 
 B<-readonly> option is forced to a true value. 
 So for the usage of Curses::UI::TextViewer see
-L<Curses::UI::TextEditor|Curses::UI::TextEditor>).
+L<Curses::UI::TextEditor|Curses::UI::TextEditor>.
 
 
 
